==> dms2dfe-1.0.6.3.tar.gz: dms2dfe-1.0.6.3/README.md <==
# `dms2dfe`

[![build status](
  http://img.shields.io/travis/rraadd88/dms2dfe/master.svg?style=flat)](
 https://travis-ci.org/rraadd88/dms2dfe) [![PyPI version](https://badge.fury.io/py/dms2dfe.svg)](https://pypi.python.org/pypi/dms2dfe)

<!--
pandoc --from=markdown --to=rst --output=README.rst R
EADME.md
-->

## Overview

dms2dfe (**D**eep **M**utational **S**canning (DMS) data to **D**istribution of **F**itness **E**ffects (DFE)) is an integrative analysis workflow designed for end-to-end enrichment analysis of Deep Mutational Scaning [1] data. Among many experimental designs Deep Mutational Scaning asssay, this workflow, currently, is only applicable for **pairwise comparisons** of samples.

## Full documentation

Latest version: http://kc-lab.github.io/dms2dfe

dms2dfe v1.0.6: http://kc-lab.github.io/dms2dfe/v1.0.6/html/

## Quick installation

To install the package written in python 2.7, simply execute following command: 

    pip install dms2dfe

## Quick usage

From bash command line, create a project directory

    dms2dfe project_directory

Insert input parameters in the configuration files (.csv) located in `project_directory/cfg`   

Run the analysis,

    dms2dfe project_directory


## Publication

**dms2dfe: Comprehensive Workflow for Analysis of Deep Mutational Scanning Data**  
Rohan Dandage, Kausik Chakraborty  
doi: http://dx.doi.org/10.1101/072645  

## Questions

Please mention them here: https://github.com/kc-lab/dms2dfe/issues .

## Footnotes

[1] Fowler, D.M., and S. Fields. 2014. Deep mutational scanning: a new style of protein science. Nature methods. 11: 801–7.

==> dms2dfe-1.0.6.5.tar.gz: dms2dfe-1.0.6.5/README.md <==
# `dms2dfe`

[![build status](
  http://img.shields.io/travis/rraadd88/dms2dfe/master.svg?style=flat)](
 https://travis-ci.org/rraadd88/dms2dfe) [![PyPI version](https://badge.fury.io/py/dms2dfe.svg)](https://pypi.python.org/pypi/dms2dfe)

<!--
pandoc --from=markdown --to=rst --output=README.rst R
EADME.md
-->

## Overview

dms2dfe (**D**eep **M**utational **S**canning (DMS) data to **D**istribution of **F**itness **E**ffects (DFE)) is an integrative analysis workflow designed for end-to-end enrichment analysis of Deep Mutational Scaning [1] data. Among many experimental designs Deep Mutational Scaning asssay, this workflow, currently, is only applicable for **pairwise comparisons** of samples.

## Full documentation

Latest version: http://kc-lab.github.io/dms2dfe

dms2dfe v1.0.6: http://kc-lab.github.io/dms2dfe/v1.0.6/html/

## Quick installation

To install the package written in python 2.7, [create a conda environment](http://kc-lab.github.io/dms2dfe/latest/html/1installation.html), simply execute following command: 

    pip install dms2dfe

## Quick usage

From bash command line, create a project directory

    dms2dfe project_directory

Insert input parameters in the configuration files (.csv) located in `project_directory/cfg`   

Run the analysis,

    dms2dfe project_directory


## Publication

**dms2dfe: Comprehensive Workflow for Analysis of Deep Mutational Scanning Data**  
Rohan Dandage, Kausik Chakraborty  
doi: http://dx.doi.org/10.1101/072645  

## Questions

Please mention them here: https://github.com/kc-lab/dms2dfe/issues .

## Footnotes

[1] Fowler, D.M., and S. Fields. 2014. Deep mutational scanning: a new style of protein science. Nature methods. 11: 801–7.
